//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","A3:WSSTR Can not create class: %s.\nPlease check the import library is right.","Ŭ  %s  մϴ.\n߰Ʈ  ´ Ȯּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","B3:WSSTR The name %s is already used by another instance.","Ʈ  %s   ܰͰ ̸ ߺϰֽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","C3:WSSTR Normal:0:,Invisible:4:,Deleted:1:,Default changed:2:,Hidden:3:",":0:,Ұ:4:,:1:,ʱⰪ:2:,Ұȭ:3:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","D3:WSSTR Target class:","ϴŬ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","E3:WSSTR Property name:","Ƽ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","F3:WSSTR Property type:","Ƽ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","G3:WSSTR Variable name:",":");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","H3:WSSTR Default value:","Ʈ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","I3:WSSTR Attribute:","ǼӼ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","J3:WSSTR Builder title:","ŸƲ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","K3:WSSTR Select menu:"," ϶:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","L3:WSSTR Warning","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","M3:WSSTR Invalid property name.\nPlease specify another name like WSNxxxx...","WSN  ۵Ǵ ùٸ Ƽ\nּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N3:WSSTR Invalid variable name...","ùٸ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","O3:WSSTR This name is already used by another procedure..."," ̸ ν\nߺϱ⿡ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR This name is already used by another external instace."," ̸ ٸ ܺμƮ̸\nߺϱ⿡ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Q3:WSSTR This name is already used by another external instace array."," ̸ ٸ ܺμƮ̸\nߺϱ⿡ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","R3:WSSTR This property name is already used by another property.","Ƽ ߺϰ־.\n ٸ ̸ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","S3:WSSTR The variable is already used."," ߺϰ־.\nٸ ̸ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","T3:WSSTR Create","ۼ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","U3:WSSTR Please specify the target class window.","Ŭ ֻ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","V3:WSSTR Please select the property.","Ƽ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR Question","Ȯ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","X3:WSSTR Is it OK to delete the property?","Ƽ ص ϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Y3:WSSTR Update","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Z3:WSSTR Create new property","Ƽ ۼ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","a3:WSSTR Edit property","Ƽ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","b3:WSSTR Delete property","Ƽ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","c3:WSSTR Type,Property name,Member name,Attribute,Default value",",Ƽ,,Ӽ,Ʈ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","d3:WSSTR New:NEW:,Edit:EDIT:,Delete:DEL:"," ۼ:NEW:,:EDIT:,:DEL:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","e3:WSSTR  Use the handler defined by user","  ڵ鷯 ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","f3:WSSTR (Normal)","()");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","g3:WSSTR (Delete)","()");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","h3:WSSTR (DefaultChange)","(ʱⰪ )");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","i3:WSSTR (Etherealize)","(Ұȭ )");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","j3:WSSTR (Invisible)","(Ұ Ӽ)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","k3:WSSTR Normal Def.:0:,Delete Def.:1:",":0:,Ʈ :1:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Target class:","ϴŬ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","m3:WSSTR Trigger name:","ƮŸ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","n3:WSSTR Define name:"," ڿ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","o3:WSSTR Define value:"," :");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","p3:WSSTR Define type:","ǼӼ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","q3:WSSTR Invalid trigger name.","̽ ȵ  ƮŸ\nּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","r3:WSSTR Invalid define string...","ùٸ  ڿ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","s3:WSSTR Please specify the define value > 31.","32 ̻  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","t3:WSSTR This trigger name is already used by another one.","ƮŸ ߺϰ־.\nٸ ̸ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","u3:WSSTR The define string is already used.","ιڿ ߺϰ־.\nٸ   ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","v3:WSSTR The value is already used.","  ߺϰ־.\nٸ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","w3:WSSTR Please select the trigger.","ƮŸ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","x3:WSSTR Is it OK to delete the trigger?","ƮŸ ص ϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","y3:WSSTR Create new trigger","Ʈ ۼ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","z3:WSSTR Edit trigger","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","A3:WSSTR Delete trigger","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","B3:WSSTR Trigger Name,Trigger def,Trigger value,Attribute","ƮŸ, ڿ, ,ǼӼ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","C3:WSSTR New:NEW:,Edit:EDIT:,Delete:DEL:"," ۼ:NEW:,:EDIT:,:DEL:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","D3:WSSTR All:",":");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","E3:WSSTR R:",":");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","F3:WSSTR G:",":");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","G3:WSSTR B:","û:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","H3:WSSTR Color:"," :");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","I3:WSSTR Name:"," ̸:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","J3:WSSTR Add user color","ǻ ߰");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","K3:WSSTR Edit user color","ǻ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","L3:WSSTR Delete user color","ǻ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","M3:WSSTR Default colors,Standard colors,User defined colors","Ʈ,Ĵ,ǻ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N3:WSSTR Please select the user color."," ǻ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","O3:WSSTR Delete the selected color: ","õ : ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR  ?","  Ͻðڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Q3:WSSTR Please select the user color to delete."," ǻ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","R3:WSSTR %s:DISP:,Save:SAVE:,Search:SEARCH:,SP,Compile:COMP:,%s:PRJ:,SP,Copy:COPY:,Paste:PASTE:,SP,Delete:DEL:","%s:DISP:,:SAVE:,˻:SEARCH:,SP,:COMP:,%s:PRJ:,SP,:COPY:,̱:PASTE:,SP,:DEL:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","S3:WSSTR Files,Instances,Properties,Procedures,Attributes",",νϽ,Ƽ,ν,⺻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","T3:WSSTR Name,Class","̸,Ŭ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","U3:WSSTR None:NONE:",":NONE:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","V3:WSSTR Display","ǥ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR Add to project","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","X3:WSSTR Dismiss","ǥ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Y3:WSSTR Remove from project","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Z3:WSSTR Add procedure","ν ߰");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","a3:WSSTR Properties","ν ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","b3:WSSTR Edit procedure","ν ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","c3:WSSTR Delete procedure","ν ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","d3:WSSTR Instance:","ϴ Ʈ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","e3:WSSTR Procedure name:","ν:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","f3:WSSTR Trigger:","⵿ Ʈ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","g3:WSSTR Function name:","⵿ :");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","h3:WSSTR Invalid procedure name...","ùٸ ν ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","i3:WSSTR Invalid function name...","ùٸ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","j3:WSSTR Invalid procedure name...","ùٸ ν ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","k3:WSSTR Invalid procedure name.\nAlready used by another proceudre name."," ̸ ν\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Invalid procedure name.\nAlready used by another instance name."," ̸ ٸ ܺμƮ̸\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","m3:WSSTR Invalid procedure name.\nAlready used by another instance array name."," ̸ ٸ ܺμƮ̸\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","n3:WSSTR Invalid function name.","ڸ    ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","o3:WSSTR Cleate %s.cpp...","%s.cpp\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","p3:WSSTR Cleate %s/%s.cpp...","%s/%s.cpp\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","o3:WSSTR Create %s.rb...","%s.rb\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","p3:WSSTR Create %s/%s.rb...","%s/%s.rb\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","o3:WSSTR Create %s.py...","%s.py\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","p3:WSSTR Create %s/%s.py...","%s/%s.py\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","o3:WSSTR Create %s.pl...","%s.pl\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","p3:WSSTR Create %s/%s.pl...","%s/%s.pl\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","o3:WSSTR Create %s.java...","%s.java\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","p3:WSSTR Create %s/%s.java...","%s/%s.java\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","o3:WSSTR Create %s.ml...","%s.ml\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","p3:WSSTR Create %s/%s.ml...","%s/%s.ml\n ۼϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","q3:WSSTR Overwrite existing file: %s?","%s\n ֽϴ.մϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","r3:WSSTR OK","ۼ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","s3:WSSTR Please specify a target instance.","Ʈ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","t3:WSSTR Please select a procedure.","ν  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","u3:WSSTR The procedure does not exist."," ν ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","v3:WSSTR Delete this procedure?","ν ص ϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","w3:WSSTR Procedure name,Trigger,Function name","ν̸,Ʈ,");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","x3:WSSTR File..."," ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","y3:WSSTR Template","ø ۼ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","z3:WSSTR Internal","ҽ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","A3:WSSTR New:NEW:,Properties:SET:,Edit procedure:EDIT:,Delete procedure:DEL:"," ۼ:NEW:,ν:SET:, :EDIT:,:DEL:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","B3:WSSTR done.\n","ϴ.\n");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","C3:WSSTR Break","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","D3:WSSTR Defaults,Environments,Imports,Compiling,Linking,Fonts,Etc..","Ʈ,ȯ漳,߰,,ũ,۲,⺻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","E3:WSSTR Default colors","Ʈ  ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","F3:WSSTR Default size","Ʈ ũ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","G3:WSSTR Grid size","׸ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","H3:WSSTR :Horizontal",":X");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","I3:WSSTR :Vertical",":Y");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","J3:WSSTR Base Window"," ̽");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","K3:WSSTR Import Libraries","߰Ʈ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","L3:WSSTR Add","߰");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","M3:WSSTR Delete","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N3:WSSTR Terminal","͹̳");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","O3:WSSTR Source editor"," ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","O3:WSSTR Editor options"," ɼ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR Web browser","Web");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Q3:WSSTR Include path","Ŭн");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","R3:WSSTR Compiler flags","÷");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","S3:WSSTR Compile mode","Ϲ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","T3:WSSTR  Debug mode"," ׸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","U3:WSSTR Application type","Application type");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","V3:WSSTR  Generate class library"," Ŭ̺귯 Ѵ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR C Compiler","C Ϸ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR CPP Compiler","CPP Ϸ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode"," , , ƽ , ƽ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Y3:WSSTR Include path","Ŭн");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Z3:WSSTR Compiler flags","÷");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","a3:WSSTR Include path","׿ Ŭн");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","b3:WSSTR Compiler flags","׿ ÷");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","c3:WSSTR Libraries","̺귯");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","d3:WSSTR Linker flags","븵Ŀ÷");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","e3:WSSTR Linker","Ŀ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","f3:WSSTR Debugger","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","f3:WSSTR Make","ũ Ŀǵ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","g3:WSSTR Runtime mode,Debug mode",",׸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","h3:WSSTR Libraries","̺귯");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","i3:WSSTR Output file","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","j3:WSSTR Libraries","׿̺귯");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","k3:WSSTR Output file","׿");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Please select a target to delete.","  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","m3:WSSTR No-name","̸-Ҹ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","n3:WSSTR Name:WSN%s  Type:%s","̸:WSN%s  :%s");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","o3:WSSTR Invalid instance name.\nAlready used by another function name..."," ̸ ν\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","p3:WSSTR Invalid instance name.\nAlready used by another instance name..."," ̸ ٸ Ʈ̸\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","q3:WSSTR Invalid instance name.\nAlready used by another instance array name..."," ̸ ٸ ̸ ߺϱ⿡\n ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","r3:WSSTR Invalid instance name.\nAlready used by project name or something..."," ̸ Ʈ ̸\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","s3:WSSTR Can not use array name for application window.","ø̼忡ؼ ̸ ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","t3:WSSTR Can not use array name for class window.","Ŭ忡  ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","u3:WSSTR Invalid instance name.\nAlready used by another procedure name..."," ̸ ν\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","v3:WSSTR Invalid instance name.\nAlready used by another external instance name..."," ̸ ٸ ܺμƮ̸\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","w3:WSSTR Invalid instance array name.\nAlready used by another window, or invalid type."," ̸ ٸ  ̸ ߺϴ°\nȤ  ġϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","x3:WSSTR Invalid instance name.\nAlready used by project name or something..."," ̸ Ʈ ̸\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","y3:WSSTR Invalid instance name.","ùٸ Ʈ̸  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","z3:WSSTR This trigger already exists."," ƮŴ մϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","A3:WSSTR This trigger already exists."," ƮŴ մϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","B3:WSSTR Can not delete the fixed trigger."," ƮŴ մϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","C3:WSSTR Please select a trigger to delete."," ƮŸ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","D3:WSSTR BaseClass","Ļ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","E3:WSSTR Base","̽");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","F3:WSSTR If you change window definition type,\nyou have to change the type of the event procedure.\nDo you contine?","Ÿ ϸ \n̺Ʈν ǰ ٸ⿡\n ϰԵ 찡ֽ Ͻðڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","G3:WSSTR If it makes the class definition window type into another type,\nit needs to change the type of the event procedure.\nDo you contine?","Ŭ  ٸ ŸԿ ϸ\n̺Ʈν ǰ ٸ⿡\n ϰԵ 찡 ϰڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","H3:WSSTR inherit base instance: %s Not Found.\nPlease specify the correct instance name.","Ļ   νϽ: %s \n ϴ. νϽ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","I3:WSSTR Invalid name.\nAlready used by another event procedure."," ̸ ν \nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","J3:WSSTR Invalid name.\nAlready used by another instance name."," ̸ ٸ Ʈ̸\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","K3:WSSTR Invalid name.\nAlready used by another instance array name."," ̸ ٸ ̸ ߺ̿\n ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","L3:WSSTR Invalid name.\nAlready used by the project name or the other one."," ̸ Ʈ ̸\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","M3:WSSTR Can not specify the array name for window.","忡 ؼ ̸ ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N3:WSSTR Can not specify the array name for class definition window.","Ŭ忡  ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","O3:WSSTR Invalid name.\nAlready used by another event procedure."," ̸ ν \nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR Invalid name.\nAlready used by another externalinstance."," ̸ ٸ ܺμƮ̸\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Q3:WSSTR Invalid array name.\nThe Array type differs from another one,or exists also another window."," ̸ ٸ  ̸ ߺϴ°\nȤ  ġϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","R3:WSSTR Invalid name.\nAlready used by the project name or the other one."," ̸ Ʈ ٸ ̸\nߺϱ⿡  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","S3:WSSTR Invalid instance name.","ùٸ Ʈ̸  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","T3:WSSTR ClassName","Ŭ̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","U3:WSSTR Normal window","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","V3:WSSTR Class definition","Ŭ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR Use object store"," ̿");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","X3:WSSTR Type","Ÿ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Y3:WSSTR Settings","Ŭ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Z3:WSSTR Properties","Ƽ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","a3:WSSTR Triggers","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","b3:WSSTR UserTriggers","Ʈ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","c3:WSSTR Icon","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","d3:WSSTR Comment","ڸƮ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","e3:WSSTR Base","Ļ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","f3:WSSTR Name","̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","g3:WSSTR File name","̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","h3:WSSTR Access","Ӽ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","i3:WSSTR Global variable","۷ι");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","j3:WSSTR Project","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","k3:WSSTR Belong to this project","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Member","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR ENCODING","ڵü");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR COMPAT","TARGET");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Platform compatible","÷ȣȯ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Look & Feel","Look & Feel");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Gradation","Gradation");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Gui Policy","GUI");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N3:WSSTR PropertyEditor","Ƽ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N3:WSSTR PropertyName:","Ƽ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N3:WSSTR PropertyType:","Ƽ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N3:WSSTR PropertyValue:","Ƽ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N3:WSSTR breaked.","ó ߴ߽ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR OBJS","߰Ʈ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","F3:WSSTR If you change class window name,\nyou have to reject your old source code\nand change the name of the event procedure.\nDo you contine?","Ŭ ϸ  ۼ ҽڵ峪\n̺Ʈν Ǹ ؾմϴ.\nϽðڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR ColorBox"," ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR MessageBox","޽ڽ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","j3:WSSTR RemoteClass","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","k3:WSSTR Generates the virtual remote class"," Ʈ Ŭ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","b3:WSSTR RemoteMethods","Ʈ ޼");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","c3:WSSTR Return type,Method name","ȯ Ÿ,޼ ̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","G3:WSSTR Parameters","Ķ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","c3:WSSTR Type,Name",",̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR Add","߰");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR Del","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR Up"," ̵");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR Down","Ʒ ̵");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","E3:WSSTR Method name:","޼ ̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","F3:WSSTR Return value type:","ȯ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","H3:WSSTR Name/Type","̸/");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","R3:WSSTR The method name is already used."," ޼ ̸ ̹ ̿Ǿ ֽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","S3:WSSTR Invalid method name.", " ޼ ̸Դϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","V3:WSSTR Please select the method.", "޼带  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","d3:WSSTR RemoteClassName:", " Ʈ Ŭ ̸:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","d3:WSSTR BaseClassName:", "Ļ  Ʈ Ŭ ̸:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Language", "");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","K3:WSSTR Edit...", "...");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR Name of the struct:","ü ̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR Name of the value:"," ̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W3:WSSTR Value:","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","c3:WSSTR Name,Value","̸,");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR Ruby","Ruby");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR Ruby(DBG)","Ruby(DBG)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR Python","Python");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR Python(DBG)","Python(DBG)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR Perl","Perl");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR Perl(DBG)","Perl(DBG)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR Java","Java");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P3:WSSTR Java(make)","Java(make)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","f3:WSSTR Static option","ũ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Statically linked","ƽ ũ(DLL )");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l3:WSSTR Dynamically linked","̳ ũ(DLL ʿ)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","K3:WSSTR Import source files","ҽ  ϱ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","A3:WSSTR Copy    :COPY:,Paste:PASTE:,SP,Properties:PROP:,Procedures:OP:,Attributes:EXPROP:,SP,Delete:DEL:","    :COPY:,ٿֱ:PASTE:,SP,Ƽ:PROP:,ν:OP:,:EXPROP:,SP,:DEL:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","A3:WSSTR Copy    :COPY:,Paste:PASTE:,SP,Properties:PROP:,Procedures:OP:,Attributes:EXPROP:,SP,Front:FRONT:,Back:BACK:,SP,Delete:DEL:","    :COPY:,ٿֱ:PASTE:,SP,Ƽ:PROP:,ν:OP:,:EXPROP:,SP,ո鿡:FRONT:,ڸ鿡:BACK:,SP,:DEL:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","A:WSSTR  //please edit here...\n","  //ó ּ.\n");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","B:WSSTR\n\n//Initializing of class...\n","\n\n//Ŭʱȭ\n");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","C:WSSTR//##### IMPORTANT: Do not edit from here  #######\n\n","//##### IMPORTANT  ⼭ʹ ϸ ȵ˴ϴ.  #######\n\n");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","D:WSSTR//##### IMPORTANT: Do not edit to here  #######\n\n","//##### IMPORTANT   ϸ ȵ˴ϴ.     #########\n");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","E:WSSTR();\n\n    // class definitions/////////////////////////////////\n","();\n\n    //Ļ / ¼ ////////////////////////////////////\n");
